# Installing Yugal
Install Python from [here](https://www.python.org/downloads/), make sure that you check 'Local Variables' and 'pip' checkbox while installation and then run the following command.
```bash
    pip install yugal
```
## Installing PHP Enviroment
PHP environment is necessary for Yugal projects to test and run. In local computer you can install any PHP environment you are comfortable with. Here we are installing XAMPP.

Installing XAMPP is very easy, just download respective package from https://www.apachefriends.org/index.html suitable for your OS and install it as you do with any other software.  

# Creating New Project
Run the command below to create new project in your server directory. Eg: `htdocs`, `public_html`.
```bash
yugal --init awesomeapp
```
[Read Full Documentation](https://yugalphp.gitbook.io/)
